=======
History
=======

0.1.4 (unreleased)
------------------

- Python 3.7 compatibility


0.1.3 (2016-09-09)
------------------

* Update to Websauna new Celery APIs

0.1.2 (2016-06-29)
------------------

* Added validation and normalization for international phone number

0.1.1 (2016-06-25)
------------------

* Added validator :py:func:`pyramid_sms.validators.valid_us_phone_number`


0.1.0 (2016-04-28)
------------------

* First release on PyPI.
